@@ -19,7 +19,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec;
 use vars qw($VERSION);
-$VERSION = sprintf "%.2f", substr(q$Rev: 271 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 286 $,4)/100;
 
 =head1 NAME
 
@@ -397,7 +397,7 @@ Build.PL.
       $ans =
 	  prompt("In case you could choose, which installer would you prefer (EUMM or MB)?",
 		 $default);
-    } while ($ans ne 'follow' && $ans ne 'ask' && $ans ne 'ignore');
+    } while (uc $ans ne 'MB' && uc $ans ne 'EUMM');
     $CPAN::Config->{prefer_installer} = $ans;
 
     $CPAN::Frontend->myprint( qq{
@@ -416,14 +416,14 @@ If you don\'t understand this question, just press ENTER.
 	prompt("Parameters for the 'perl Makefile.PL' command?
 Typical frequently used settings:
 
-    PREFIX=~/perl       non-root users (please see manual for more hints)
+    PREFIX=~/perl    # non-root users (please see manual for more hints)
 
 Your choice: ",$default);
     $default = $CPAN::Config->{make_arg} || "";
     $CPAN::Config->{make_arg} = prompt("Parameters for the 'make' command?
 Typical frequently used setting:
 
-    -j3              dual processor system
+    -j3              # dual processor system
 
 Your choice: ",$default);
 
@@ -443,7 +443,53 @@ or some such. Your choice: ",$default);
 	prompt("Parameters for the 'make install' command?
 Typical frequently used setting:
 
-    UNINST=1         to always uninstall potentially conflicting files
+    UNINST=1         # to always uninstall potentially conflicting files
+
+Your choice: ",$default);
+
+    $CPAN::Frontend->myprint( qq{
+
+The next questions deal with Module::Build support.
+
+A Build.PL is run by perl in a separate process. Likewise we run
+'./Build' and './Build install' in separate processes. If you have any
+parameters you want to pass to the calls, please specify them here.
+
+});
+
+    $default = $CPAN::Config->{mbuildpl_arg} || "";
+    $CPAN::Config->{mbuildpl_arg} =
+	prompt("Parameters for the 'perl Build.PL' command?
+Typical frequently used settings:
+
+    --install_base /home/xxx             # different installation directory
+
+Your choice: ",$default);
+    $default = $CPAN::Config->{mbuild_arg} || "";
+    $CPAN::Config->{mbuild_arg} = prompt("Parameters for the './Build' command?
+Setting might be:
+
+    --extra_linker_flags -L/usr/foo/lib  # non-standard library location
+
+Your choice: ",$default);
+
+    $default = $CPAN::Config->{mbuild_install_build_command} || "./Build";
+    $CPAN::Config->{mbuild_install_build_command} =
+	prompt("Do you want to use a different command for './Build install'?
+Sudo users will probably prefer:
+
+    sudo ./Build
+or
+    /path1/to/sudo -u admin_account ./Build
+
+or some such. Your choice: ",$default);
+
+    $default = $CPAN::Config->{mbuild_install_arg} || "";
+    $CPAN::Config->{mbuild_install_arg} =
+	prompt("Parameters for the './Build install' command?
+Typical frequently used setting:
+
+    --uninst 1                           # uninstall conflicting files
 
 Your choice: ",$default);
 
@@ -465,7 +511,7 @@ the default and recommended setting.
 
     $default = $CPAN::Config->{inactivity_timeout} || 0;
     $CPAN::Config->{inactivity_timeout} =
-	prompt("Timeout for inactivity during Makefile.PL?",$default);
+	prompt("Timeout for inactivity during {Makefile,Build}.PL?",$default);
 
     # Proxies
 
@@ -531,7 +577,7 @@ be echoed to the terminal!
     $CPAN::Config->{'getcwd'} = 'cwd';
 
     $CPAN::Frontend->myprint("\n\n");
-    CPAN::Config->commit($configpm);
+    CPAN::HandleConfig->commit($configpm);
 }
 
 sub conf_sites {
